package ru.redguy.dynamicshop.api;

import org.bukkit.Material;
import org.bukkit.configuration.serialization.ConfigurationSerializable;
import org.bukkit.configuration.serialization.SerializableAs;
import org.bukkit.inventory.ItemStack;
import org.jetbrains.annotations.Contract;
import org.jetbrains.annotations.NotNull;

import java.util.HashMap;
import java.util.Map;

@SerializableAs("ShopItem")
public class ShopItem implements Cloneable, ConfigurationSerializable {
    private ItemStack item;
    private double price;

    public ShopItem(ItemStack item, double price) {
        this.item = item;
        this.price = price;
    }

    public ItemStack getItem() {
        return item;
    }

    public void setItem(ItemStack item) {
        this.item = item;
    }

    public double getPrice() {
        return price;
    }

    public void setPrice(double price) {
        this.price = price;
    }

    @Contract("_ -> new")
    public static @NotNull ShopItem deserialize(@NotNull Map<String, Object> args) {
        ItemStack item = new ItemStack(Material.AIR);
        double price = 0;
        if(args.containsKey("item")) {
            item = (ItemStack) args.get("item");
        }

        if(args.containsKey("price")) {
            price = (Double) args.get("price");
        }

        return new ShopItem(item,price);
    }

    @Override
    public @NotNull Map<String, Object> serialize() {
        HashMap<String, Object> map = new HashMap<>();
        map.put("item",item);
        map.put("price",price);
        return map;
    }

    @Override
    public ShopItem clone() {
        try {
            ShopItem clone = (ShopItem) super.clone();
            clone.item = item;
            clone.price = price;
            return clone;
        } catch (CloneNotSupportedException e) {
            throw new AssertionError();
        }
    }
}
